module EmmetNotifications
  class Message < ActiveRecord::Base
    extend ::EnumerateIt

    self.table_name = :notifications_messages

    has_enumeration_for :kind, with: MessageType, required: true, create_helpers: true

    validates :title, presence: true
    validates :slug, presence: true, uniqueness: true
    validates :subject, presence: true
    validates :description, presence: true
    validates :content, presence: true

    before_validation :generate_slug

    def send_to(email, options = {})
      EmmetNotifications::Senders::Email.new(self).send_to_sender(email, options)
    end

    def self.send_to_by(slug, email, options = {})
      message = find_by_slug(slug)
      message.send_to(email, options) if message
      message
    end

    private

    def generate_slug
      self.slug = self.title.underscore.gsub(/[\/|\s]+/, '_') if self.title.present?
    end
  end
end
